Documentation
¶
Index ¶
Constants ¶
const ( // ContainerID defines the id to be used as the container // registration id of a config instance, as a base id of all other config // package instances registered in the application container. ContainerID = gapp.ContainerID + ".config" // ContainerDecoderStrategyTag defines the tag to be assigned to all // container decoders strategies. ContainerDecoderStrategyTag = ContainerID + ".decoder.strategy" // ContainerDecoderStrategyYAMLID defines the id to be used as the // container registration id of a yaml config decoder factory strategy // instance. ContainerDecoderStrategyYAMLID = ContainerID + ".decoder.strategy.yaml" // ContainerDecoderStrategyJSONID defines the id to be used as the // container registration id of a json config decoder factory strategy // instance. ContainerDecoderStrategyJSONID = ContainerID + ".decoder.strategy.json" // ContainerDecoderFactoryID defines the id to be used as the // container registration id of a config decoder factory instance. ContainerDecoderFactoryID = ContainerID + ".decoder.factory" // ContainerSourceStrategyTag defines the tag to be assigned to all // container source strategies. ContainerSourceStrategyTag = ContainerID + ".source.strategy" // ContainerSourceStrategyFileID defines the id to be used as the // container registration id of a config file source factory strategy // instance. ContainerSourceStrategyFileID = ContainerID + ".source.strategy.file" // ContainerSourceStrategyFileObservableID defines the id to be used // as the container registration id of a config observable file source // factory strategy instance. ContainerSourceStrategyFileObservableID = ContainerID + ".source.strategy.file_observable" // ContainerSourceStrategyRemoteID defines the id to be used as the // container registration id of a config remote source factory strategy // instance. ContainerSourceStrategyRemoteID = ContainerID + ".source.strategy.remote" // ContainerSourceStrategyRemoteObservableID defines the id to be used // as the container registration id of a config observable remote source // factory strategy instance. ContainerSourceStrategyRemoteObservableID = ContainerID + ".source.strategy.remote_observable" // ContainerSourceStrategyEnvID defines the id to be used as // the container registration id of a config environment source // factory strategy instance. ContainerSourceStrategyEnvID = ContainerID + ".source.strategy.env" // ContainerSourceFactoryID defines the id to be used as the // container registration id config source factory instance. ContainerSourceFactoryID = ContainerID + ".source.factory" // ContainerLoaderID defines the id to be used as the container // registration id of a config loader instance. ContainerLoaderID = ContainerID + ".loader" )
Variables ¶
var ( // ErrNilPointer defines a nil pointer argument error ErrNilPointer = gapp.ErrNilPointer // ErrConversion defines a type conversion error ErrConversion = gapp.ErrConversion )
var ( // ObserveFrequency defines the id to be used as the default of a // config observable source frequency time in seconds. ObserveFrequency = genv.Int("GAPP_CONFIG_OBSERVE_FREQUENCY", 0) // LoaderActive defines if the config loader should be executed // while the provider boot LoaderActive = genv.Bool("GAPP_CONFIG_LOADER_ACTIVE", true) )
Functions ¶
This section is empty.
Types ¶
type Provider ¶ added in v1.6.0
type Provider struct{}
Provider defines the gapp/config module service provider to be used on the application initialization to register the config service.
Click to show internal directories.
Click to hide internal directories.